@@ -1,10 +1,25 @@
+#
+#  This file is part of Sequana software
+#
+#  Copyright (c) 2016-2021 - Sequana Development Team
+##
+#  Distributed under the terms of the 3-clause BSD license.
+#  The full license is in the LICENSE file, distributed with this software.
+#
+#  website: https://github.com/sequana/sequana
+#  documentation: http://sequana.readthedocs.io
+#
+##############################################################################
 import sys
 import os
 import argparse
+import subprocess
 
 from sequana_pipetools.options import *
+from sequana_pipetools.options import before_pipeline
 from sequana_pipetools.misc import Colors
 from sequana_pipetools.info import sequana_epilog, sequana_prolog
+from sequana_pipetools import SequanaManager
 
 col = Colors()
 
@@ -34,18 +49,26 @@ class Options(argparse.ArgumentParser):
 
         pipeline_group = self.add_argument_group("pipeline")
         pipeline_group.add_argument("--mapper", default='bwa',
-             choices=['bwa', 'minimap2', 'bowtie2'])
+             choices=['bwa', 'minimap2', 'bowtie2'], 
+            help="Choose one of the valid mapper")
         pipeline_group.add_argument("--reference-file", required=True,
-             )
+             help="You input reference file in fasta format")
         pipeline_group.add_argument("--annotation-file",
             help="Used by the sequana_coverage tool if provided" )
 
         pipeline_group.add_argument("--do-coverage", action="store_true",
             help="Use sequana_coverage (prokaryotes)" )
 
+        pipeline_group.add_argument("--pacbio", action="store_true",
+            help="If set, automatically set the input-readtag to None and set minimap2 options to -x map-pb" )
+
         pipeline_group.add_argument("--create-bigwig", action="store_true",
             help="create the bigwig files from the BAM files" )
 
+        self.add_argument("--run", default=False, action="store_true",
+            help="execute the pipeline directly")
+
+
     def parse_args(self, *args):
         args_list = list(*args)
         if "--from-project" in args_list:
@@ -66,15 +89,11 @@ def main(args=None):
         args = sys.argv
 
     # whatever needs to be called by all pipeline before the options parsing
-    from sequana_pipetools.options import before_pipeline
     before_pipeline(NAME)
 
     # option parsing including common epilog
     options = Options(NAME, epilog=sequana_epilog).parse_args(args[1:])
 
-
-    from sequana.pipelines_common import SequanaManager
-
     # the real stuff is here
     manager = SequanaManager(options, NAME)
 
@@ -104,11 +123,18 @@ def main(args=None):
         if options.create_bigwig:
             cfg.general.create_bigwig = True
 
+        if options.pacbio:
+            cfg.minimap2.options = " -x map-pb "
+            cfg.input_readtag = ""
+
+
 
     # finalise the command and save it; copy the snakemake. update the config
     # file and save it.
     manager.teardown()
 
+    if options.run:
+        subprocess.Popen(["sh", '{}.sh'.format(NAME)], cwd=options.workdir)
 
 if __name__ == "__main__":
     main()
